function [fitness,feval] = pureRS(n)
% [fitness,feval] = pureRS(n)
% Pure RS for bitstrings of size(n) for maximizing the OneMax function
% Solutions sampled uniformly in {0,1}^n 
% 
% fitness: a vector with best-so-far function values
% feval: number of function evaluations until optimum was found

% initialization:
x = round(rand(n,1));    % sample a point uniformly in {0,1}^n
f = onemax(x);           % evaluate this point
feval = 1;

fitness = f;             % store best-so-far function value

% "generational" cycle:
while (f < n)
   x = round(rand(n,1)); % equiv. to 'randi(2, [n,1]) - ones(n,1)'
   fx = onemax(x);
   f = max(f,fx);
   fitness = [fitness f];
   feval = feval+1;
end
